# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/graph/v1/graph.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.arrow.v1 import arrow_pb2 as chalk_dot_arrow_dot_v1_dot_arrow__pb2
from chalk._gen.chalk.expression.v1 import expression_pb2 as chalk_dot_expression_dot_v1_dot_expression__pb2
from chalk._gen.chalk.graph.v1 import sources_pb2 as chalk_dot_graph_dot_v1_dot_sources__pb2
from chalk._gen.chalk.graph.v2 import sources_pb2 as chalk_dot_graph_dot_v2_dot_sources__pb2
from chalk._gen.chalk.lsp.v1 import lsp_pb2 as chalk_dot_lsp_dot_v1_dot_lsp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1a\x63halk/graph/v1/graph.proto\x12\x0e\x63halk.graph.v1\x1a\x1a\x63halk/arrow/v1/arrow.proto\x1a$chalk/expression/v1/expression.proto\x1a\x1c\x63halk/graph/v1/sources.proto\x1a\x1c\x63halk/graph/v2/sources.proto\x1a\x16\x63halk/lsp/v1/lsp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xdc\x05\n\x05Graph\x12=\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32\x1a.chalk.graph.v1.FeatureSetR\x0b\x66\x65\x61tureSets\x12\x36\n\tresolvers\x18\x02 \x03(\x0b\x32\x18.chalk.graph.v1.ResolverR\tresolvers\x12I\n\x10stream_resolvers\x18\x03 \x03(\x0b\x32\x1e.chalk.graph.v1.StreamResolverR\x0fstreamResolvers\x12\x43\n\x0esink_resolvers\x18\x04 \x03(\x0b\x32\x1c.chalk.graph.v1.SinkResolverR\rsinkResolvers\x12M\n\x10\x64\x61tabase_sources\x18\x05 \x03(\x0b\x32\x1e.chalk.graph.v1.DatabaseSourceB\x02\x18\x01R\x0f\x64\x61tabaseSources\x12G\n\x0estream_sources\x18\x06 \x03(\x0b\x32\x1c.chalk.graph.v1.StreamSourceB\x02\x18\x01R\rstreamSources\x12?\n\rnamed_queries\x18\x07 \x03(\x0b\x32\x1a.chalk.graph.v1.NamedQueryR\x0cnamedQueries\x12N\n\x13\x64\x61tabase_sources_v2\x18\x08 \x03(\x0b\x32\x1e.chalk.graph.v2.DatabaseSourceR\x11\x64\x61tabaseSourcesV2\x12Y\n\x16\x64\x61tabase_source_groups\x18\n \x03(\x0b\x32#.chalk.graph.v2.DatabaseSourceGroupR\x14\x64\x61tabaseSourceGroups\x12H\n\x11stream_sources_v2\x18\t \x03(\x0b\x32\x1c.chalk.graph.v2.StreamSourceR\x0fstreamSourcesV2"\xa2\x02\n\x0cOverlayGraph\x12=\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32\x1a.chalk.graph.v1.FeatureSetR\x0b\x66\x65\x61tureSets\x12\x42\n\x0e\x66\x65\x61ture_fields\x18\x02 \x03(\x0b\x32\x1b.chalk.graph.v1.FeatureTypeR\rfeatureFields\x12\x36\n\tresolvers\x18\x03 \x03(\x0b\x32\x18.chalk.graph.v1.ResolverR\tresolvers\x12W\n\x17generated_sql_resolvers\x18\x04 \x03(\x0b\x32\x1f.chalk.graph.v1.SQLResolverInfoR\x15generatedSqlResolvers"\x92\x08\n\nNamedQuery\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12(\n\rquery_version\x18\x02 \x01(\tH\x00R\x0cqueryVersion\x88\x01\x01\x12\x14\n\x05input\x18\x03 \x03(\tR\x05input\x12\x16\n\x06output\x18\x04 \x03(\tR\x06output\x12\x12\n\x04tags\x18\x05 \x03(\tR\x04tags\x12%\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05owner\x18\x07 \x01(\tH\x02R\x05owner\x88\x01\x01\x12\x38\n\x04meta\x18\x08 \x03(\x0b\x32$.chalk.graph.v1.NamedQuery.MetaEntryR\x04meta\x12G\n\tstaleness\x18\t \x03(\x0b\x32).chalk.graph.v1.NamedQuery.StalenessEntryR\tstaleness\x12W\n\x0fplanner_options\x18\n \x03(\x0b\x32..chalk.graph.v1.NamedQuery.PlannerOptionsEntryR\x0eplannerOptions\x12\x1b\n\tfile_name\x18\x0b \x01(\tR\x08\x66ileName\x12(\n\rdeployment_id\x18\x0c \x01(\tH\x03R\x0c\x64\x65ploymentId\x88\x01\x01\x12\\\n\x15source_file_reference\x18\r \x01(\x0b\x32#.chalk.graph.v1.SourceFileReferenceH\x04R\x13sourceFileReference\x88\x01\x01\x12<\n\x1a\x61\x64\x64itional_logged_features\x18\x0e \x03(\tR\x18\x61\x64\x64itionalLoggedFeatures\x12:\n\x17valid_plan_not_required\x18\x0f \x01(\x08H\x05R\x14validPlanNotRequired\x88\x01\x01\x1a\x37\n\tMetaEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1aW\n\x0eStalenessEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12/\n\x05value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x05value:\x02\x38\x01\x1a\x41\n\x13PlannerOptionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x10\n\x0e_query_versionB\x0e\n\x0c_descriptionB\x08\n\x06_ownerB\x10\n\x0e_deployment_idB\x18\n\x16_source_file_referenceB\x1a\n\x18_valid_plan_not_required"\xaa\x03\n\nFeatureSet\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x37\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x1b.chalk.graph.v1.FeatureTypeR\x08\x66\x65\x61tures\x12O\n\x16max_staleness_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x14maxStalenessDuration\x12!\n\x0cis_singleton\x18\x04 \x01(\x08R\x0bisSingleton\x12\x12\n\x04tags\x18\x05 \x03(\tR\x04tags\x12\x19\n\x05owner\x18\x06 \x01(\tH\x00R\x05owner\x88\x01\x01\x12\x15\n\x03\x64oc\x18\x07 \x01(\tH\x01R\x03\x64oc\x88\x01\x01\x12\x36\n\x15\x65tl_offline_to_online\x18\x08 \x01(\x08H\x02R\x12\x65tlOfflineToOnline\x88\x01\x01\x12"\n\nclass_path\x18\t \x01(\tH\x03R\tclassPath\x88\x01\x01\x42\x08\n\x06_ownerB\x06\n\x04_docB\x18\n\x16_etl_offline_to_onlineB\r\n\x0b_class_path"\xa2\x03\n\x0b\x46\x65\x61tureType\x12;\n\x06scalar\x18\x01 \x01(\x0b\x32!.chalk.graph.v1.ScalarFeatureTypeH\x00R\x06scalar\x12<\n\x07has_one\x18\x02 \x01(\x0b\x32!.chalk.graph.v1.HasOneFeatureTypeH\x00R\x06hasOne\x12?\n\x08has_many\x18\x03 \x01(\x0b\x32".chalk.graph.v1.HasManyFeatureTypeH\x00R\x07hasMany\x12K\n\x0c\x66\x65\x61ture_time\x18\x04 \x01(\x0b\x32&.chalk.graph.v1.FeatureTimeFeatureTypeH\x00R\x0b\x66\x65\x61tureTime\x12\x41\n\x08windowed\x18\x05 \x01(\x0b\x32#.chalk.graph.v1.WindowedFeatureTypeH\x00R\x08windowed\x12?\n\x08group_by\x18\x06 \x01(\x0b\x32".chalk.graph.v1.GroupByFeatureTypeH\x00R\x07groupByB\x06\n\x04type"\xa9\x01\n\x10\x46\x65\x61tureReference\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x34\n\x04path\x18\x03 \x03(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x04path\x12-\n\x02\x64\x66\x18\x04 \x01(\x0b\x32\x1d.chalk.graph.v1.DataFrameTypeR\x02\x64\x66"\xb3\x02\n\rDataFrameType\x12%\n\x0eroot_namespace\x18\x01 \x01(\tR\rrootNamespace\x12K\n\x10required_columns\x18\x02 \x03(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x0frequiredColumns\x12K\n\x10optional_columns\x18\x03 \x03(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x0foptionalColumns\x12<\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x06\x66ilter\x12\x19\n\x05limit\x18\x05 \x01(\x04H\x00R\x05limit\x88\x01\x01\x42\x08\n\x06_limit"\x93\x06\n\x12GroupByFeatureType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1f\n\x0bis_nullable\x18\x03 \x01(\x08R\nisNullable\x12.\n\x10internal_version\x18\x04 \x01(\x04H\x00R\x0finternalVersion\x88\x01\x01\x12\x38\n\narrow_type\x18\x05 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType\x12\x43\n\x0b\x61ggregation\x18\x06 \x01(\x0b\x32!.chalk.graph.v1.WindowAggregationR\x0b\x61ggregation\x12\x44\n\x10window_durations\x18\x07 \x03(\x0b\x32\x19.google.protobuf.DurationR\x0fwindowDurations\x12\x44\n\nexpression\x18\x08 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\nexpression\x12@\n\rdefault_value\x18\t \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x0c\x64\x65\x66\x61ultValue\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05owner\x18\x0c \x01(\tH\x02R\x05owner\x88\x01\x01\x12\x43\n\x0bvalidations\x18\r \x03(\x0b\x32!.chalk.graph.v1.FeatureValidationR\x0bvalidations\x12%\n\x0e\x61ttribute_name\x18\x0e \x01(\tR\rattributeName\x12<\n\x1aunversioned_attribute_name\x18\x0f \x01(\tR\x18unversionedAttributeNameB\x13\n\x11_internal_versionB\x0e\n\x0c_descriptionB\x08\n\x06_owner"\x90\x0c\n\x11ScalarFeatureType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12)\n\x10is_autogenerated\x18\x03 \x01(\x08R\x0fisAutogenerated\x12\x1d\n\nno_display\x18\x04 \x01(\x08R\tnoDisplay\x12\x1d\n\nis_primary\x18\x05 \x01(\x08R\tisPrimary\x12\x1f\n\x0bis_nullable\x18\x06 \x01(\x08R\nisNullable\x12.\n\x10internal_version\x18\x07 \x01(\x04H\x00R\x0finternalVersion\x88\x01\x01\x12O\n\x16max_staleness_duration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationR\x14maxStalenessDuration\x12K\n\x14offline_ttl_duration\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationR\x12offlineTtlDuration\x12\x38\n\narrow_type\x18\x0b \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType\x12\x35\n\x07version\x18\x0c \x01(\x0b\x32\x1b.chalk.graph.v1.VersionInfoR\x07version\x12;\n\x0bwindow_info\x18\r \x01(\x0b\x32\x1a.chalk.graph.v1.WindowInfoR\nwindowInfo\x12@\n\rdefault_value\x18\x0e \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x0c\x64\x65\x66\x61ultValue\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05owner\x18\x11 \x01(\tH\x02R\x05owner\x88\x01\x01\x12\x44\n\nexpression\x18\x12 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\nexpression\x12\x43\n\x0bvalidations\x18\x13 \x03(\x0b\x32!.chalk.graph.v1.FeatureValidationR\x0bvalidations\x12;\n\x08last_for\x18\x14 \x01(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x07lastFor\x12\x36\n\x15\x65tl_offline_to_online\x18\x15 \x01(\x08H\x03R\x12\x65tlOfflineToOnline\x88\x01\x01\x12:\n\x19is_distance_pseudofeature\x18\x16 \x01(\x08R\x17isDistancePseudofeature\x12%\n\x0e\x61ttribute_name\x18\x17 \x01(\tR\rattributeName\x12#\n\ris_deprecated\x18\x18 \x01(\x08R\x0cisDeprecated\x12\x44\n\x0e\x63\x61\x63he_strategy\x18\x19 \x01(\x0e\x32\x1d.chalk.graph.v1.CacheStrategyR\rcacheStrategy\x12&\n\x0cstore_online\x18\x1a \x01(\x08H\x04R\x0bstoreOnline\x88\x01\x01\x12(\n\rstore_offline\x18\x1b \x01(\x08H\x05R\x0cstoreOffline\x88\x01\x01\x12<\n\x1aunversioned_attribute_name\x18\x1c \x01(\tR\x18unversionedAttributeName\x12N\n\x0erich_type_info\x18\x1d \x01(\x0b\x32#.chalk.graph.v1.FeatureRichTypeInfoH\x06R\x0crichTypeInfo\x88\x01\x01\x42\x13\n\x11_internal_versionB\x0e\n\x0c_descriptionB\x08\n\x06_ownerB\x18\n\x16_etl_offline_to_onlineB\x0f\n\r_store_onlineB\x10\n\x0e_store_offlineB\x11\n\x0f_rich_type_info"\xcd\x03\n\x11HasOneFeatureType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12+\n\x11\x66oreign_namespace\x18\x03 \x01(\tR\x10\x66oreignNamespace\x12\x38\n\x04join\x18\x04 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04join\x12\x1f\n\x0bis_nullable\x18\x05 \x01(\x08R\nisNullable\x12)\n\x10is_autogenerated\x18\x06 \x01(\x08R\x0fisAutogenerated\x12\x12\n\x04tags\x18\x07 \x03(\tR\x04tags\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05owner\x18\t \x01(\tH\x01R\x05owner\x88\x01\x01\x12%\n\x0e\x61ttribute_name\x18\n \x01(\tR\rattributeName\x12<\n\x1aunversioned_attribute_name\x18\x0b \x01(\tR\x18unversionedAttributeNameB\x0e\n\x0c_descriptionB\x08\n\x06_owner"\xfe\x03\n\x12HasManyFeatureType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12+\n\x11\x66oreign_namespace\x18\x03 \x01(\tR\x10\x66oreignNamespace\x12\x38\n\x04join\x18\x04 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04join\x12)\n\x10is_autogenerated\x18\x05 \x01(\x08R\x0fisAutogenerated\x12O\n\x16max_staleness_duration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x14maxStalenessDuration\x12\x12\n\x04tags\x18\x07 \x03(\tR\x04tags\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05owner\x18\t \x01(\tH\x01R\x05owner\x88\x01\x01\x12%\n\x0e\x61ttribute_name\x18\n \x01(\tR\rattributeName\x12<\n\x1aunversioned_attribute_name\x18\x0b \x01(\tR\x18unversionedAttributeNameB\x0e\n\x0c_descriptionB\x08\n\x06_owner"\x8c\x02\n\x16\x46\x65\x61tureTimeFeatureType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12)\n\x10is_autogenerated\x18\x03 \x01(\x08R\x0fisAutogenerated\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05owner\x18\x06 \x01(\tH\x01R\x05owner\x88\x01\x01\x12%\n\x0e\x61ttribute_name\x18\x07 \x01(\tR\rattributeNameB\x0e\n\x0c_descriptionB\x08\n\x06_owner"\x9d\x02\n\x13WindowedFeatureType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12)\n\x10is_autogenerated\x18\x03 \x01(\x08R\x0fisAutogenerated\x12\x44\n\x10window_durations\x18\x04 \x03(\x0b\x32\x19.google.protobuf.DurationR\x0fwindowDurations\x12%\n\x0e\x61ttribute_name\x18\x05 \x01(\tR\rattributeName\x12<\n\x1aunversioned_attribute_name\x18\x06 \x01(\tR\x18unversionedAttributeName"\xa9\x08\n\x11WindowAggregation\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12;\n\x08group_by\x18\x02 \x03(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x07groupBy\x12\x42\n\x0f\x62ucket_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0e\x62ucketDuration\x12 \n\x0b\x61ggregation\x18\x04 \x01(\tR\x0b\x61ggregation\x12H\n\x0c\x61ggregate_on\x18\x05 \x01(\x0b\x32 .chalk.graph.v1.FeatureReferenceH\x00R\x0b\x61ggregateOn\x88\x01\x01\x12\x38\n\narrow_type\x18\x06 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType\x12>\n\x07\x66ilters\x18\x07 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x07\x66ilters\x12\x30\n\x11\x62\x61\x63kfill_resolver\x18\x08 \x01(\tH\x01R\x10\x62\x61\x63kfillResolver\x88\x01\x01\x12\\\n\x1a\x62\x61\x63kfill_lookback_duration\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationH\x02R\x18\x62\x61\x63kfillLookbackDuration\x88\x01\x01\x12O\n\x13\x62\x61\x63kfill_start_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03R\x11\x62\x61\x63kfillStartTime\x88\x01\x01\x12\x34\n\x13\x63ontinuous_resolver\x18\x0b \x01(\tH\x04R\x12\x63ontinuousResolver\x88\x01\x01\x12\\\n\x1a\x63ontinuous_buffer_duration\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationH\x05R\x18\x63ontinuousBufferDuration\x88\x01\x01\x12\x30\n\x11\x62\x61\x63kfill_schedule\x18\r \x01(\tH\x06R\x10\x62\x61\x63kfillSchedule\x88\x01\x01\x12=\n\x0c\x62ucket_start\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x62ucketStartB\x0f\n\r_aggregate_onB\x14\n\x12_backfill_resolverB\x1d\n\x1b_backfill_lookback_durationB\x16\n\x14_backfill_start_timeB\x16\n\x14_continuous_resolverB\x1d\n\x1b_continuous_buffer_durationB\x14\n\x12_backfill_schedule"\x9d\x01\n\nWindowInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08\x64uration\x12H\n\x0b\x61ggregation\x18\x02 \x01(\x0b\x32!.chalk.graph.v1.WindowAggregationH\x00R\x0b\x61ggregation\x88\x01\x01\x42\x0e\n\x0c_aggregation"\x8c\x01\n\x0c\x46\x65\x61tureInput\x12:\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x07\x66\x65\x61ture\x12@\n\rdefault_value\x18\x02 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x0c\x64\x65\x66\x61ultValue"\xbf\x01\n\rResolverInput\x12\x38\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x1c.chalk.graph.v1.FeatureInputH\x00R\x07\x66\x65\x61ture\x12/\n\x02\x64\x66\x18\x02 \x01(\x0b\x32\x1d.chalk.graph.v1.DataFrameTypeH\x00R\x02\x64\x66\x12\x35\n\x05state\x18\x03 \x01(\x0b\x32\x1d.chalk.graph.v1.ResolverStateH\x00R\x05stateB\x0c\n\nannotation"\x8d\x01\n\x0eResolverOutput\x12<\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32 .chalk.graph.v1.FeatureReferenceH\x00R\x07\x66\x65\x61ture\x12/\n\x02\x64\x66\x18\x02 \x01(\x0b\x32\x1d.chalk.graph.v1.DataFrameTypeH\x00R\x02\x64\x66\x42\x0c\n\nannotation"\xf9\t\n\x08Resolver\x12\x10\n\x03\x66qn\x18\x01 \x01(\tR\x03\x66qn\x12\x30\n\x04kind\x18\x02 \x01(\x0e\x32\x1c.chalk.graph.v1.ResolverKindR\x04kind\x12\x35\n\x06inputs\x18\x03 \x03(\x0b\x32\x1d.chalk.graph.v1.ResolverInputR\x06inputs\x12\x38\n\x07outputs\x18\x04 \x03(\x0b\x32\x1e.chalk.graph.v1.ResolverOutputR\x07outputs\x12!\n\x0cis_generator\x18\x05 \x01(\x08R\x0bisGenerator\x12N\n\x0c\x64\x61ta_sources\x18\x06 \x03(\x0b\x32\'.chalk.graph.v1.DatabaseSourceReferenceB\x02\x18\x01R\x0b\x64\x61taSources\x12&\n\x0cmachine_type\x18\x07 \x01(\tH\x00R\x0bmachineType\x88\x01\x01\x12\x12\n\x04tags\x18\x08 \x03(\tR\x04tags\x12\x19\n\x05owner\x18\t \x01(\tH\x01R\x05owner\x88\x01\x01\x12\x15\n\x03\x64oc\x18\n \x01(\tH\x02R\x03\x64oc\x88\x01\x01\x12"\n\x0c\x65nvironments\x18\x0b \x03(\tR\x0c\x65nvironments\x12\x44\n\x10timeout_duration\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationR\x0ftimeoutDuration\x12\x34\n\x08schedule\x18\r \x01(\x0b\x32\x18.chalk.graph.v1.ScheduleR\x08schedule\x12\x38\n\x04when\x18\x0e \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04when\x12J\n\x0b\x63ron_filter\x18\x0f \x01(\x0b\x32).chalk.graph.v1.CronFilterWithFeatureArgsR\ncronFilter\x12=\n\x08\x66unction\x18\x10 \x01(\x0b\x32!.chalk.graph.v1.FunctionReferenceR\x08\x66unction\x12\x41\n\rresource_hint\x18\x11 \x01(\x0e\x32\x1c.chalk.graph.v1.ResourceHintR\x0cresourceHint\x12\x1b\n\tis_static\x18\x12 \x01(\x08R\x08isStatic\x12\x1e\n\x08is_total\x18\x13 \x01(\x08H\x03R\x07isTotal\x88\x01\x01\x12\x1b\n\tunique_on\x18\x14 \x03(\tR\x08uniqueOn\x12%\n\x0epartitioned_by\x18\x15 \x03(\tR\rpartitionedBy\x12O\n\x0f\x64\x61ta_sources_v2\x18\x16 \x03(\x0b\x32\'.chalk.graph.v2.DatabaseSourceReferenceR\rdataSourcesV2\x12O\n\x10static_operation\x18\x17 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x0fstaticOperation\x12K\n\x0csql_settings\x18\x18 \x01(\x0b\x32#.chalk.graph.v1.SQLResolverSettingsH\x04R\x0bsqlSettings\x88\x01\x01\x42\x0f\n\r_machine_typeB\x08\n\x06_ownerB\x06\n\x04_docB\x0b\n\t_is_totalB\x0f\n\r_sql_settings"\xc1\x07\n\x0cSinkResolver\x12\x10\n\x03\x66qn\x18\x01 \x01(\tR\x03\x66qn\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x1d.chalk.graph.v1.ResolverInputR\x06inputs\x12$\n\x0b\x62uffer_size\x18\x03 \x01(\x04H\x01R\nbufferSize\x88\x01\x01\x12\x46\n\x11\x64\x65\x62ounce_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10\x64\x65\x62ounceDuration\x12G\n\x12max_delay_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10maxDelayDuration\x12\x16\n\x06upsert\x18\x06 \x01(\x08R\x06upsert\x12P\n\rstream_source\x18\x07 \x01(\x0b\x32%.chalk.graph.v1.StreamSourceReferenceB\x02\x18\x01H\x00R\x0cstreamSource\x12V\n\x0f\x64\x61tabase_source\x18\x08 \x01(\x0b\x32\'.chalk.graph.v1.DatabaseSourceReferenceB\x02\x18\x01H\x00R\x0e\x64\x61tabaseSource\x12Q\n\x10stream_source_v2\x18\x0f \x01(\x0b\x32%.chalk.graph.v2.StreamSourceReferenceH\x00R\x0estreamSourceV2\x12W\n\x12\x64\x61tabase_source_v2\x18\x10 \x01(\x0b\x32\'.chalk.graph.v2.DatabaseSourceReferenceH\x00R\x10\x64\x61tabaseSourceV2\x12&\n\x0cmachine_type\x18\t \x01(\tH\x02R\x0bmachineType\x88\x01\x01\x12\x15\n\x03\x64oc\x18\n \x01(\tH\x03R\x03\x64oc\x88\x01\x01\x12\x19\n\x05owner\x18\x0b \x01(\tH\x04R\x05owner\x88\x01\x01\x12"\n\x0c\x65nvironments\x18\x0c \x03(\tR\x0c\x65nvironments\x12\x44\n\x10timeout_duration\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x0ftimeoutDuration\x12=\n\x08\x66unction\x18\x0e \x01(\x0b\x32!.chalk.graph.v1.FunctionReferenceR\x08\x66unctionB\r\n\x0bintegrationB\x0e\n\x0c_buffer_sizeB\x0f\n\r_machine_typeB\x06\n\x04_docB\x08\n\x06_owner"\xd7\x03\n\tParseInfo\x12H\n\x0eparse_function\x18\x01 \x01(\x0b\x32!.chalk.graph.v1.FunctionReferenceR\rparseFunction\x12T\n\x19parse_function_input_type\x18\x02 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\x16parseFunctionInputType\x12V\n\x1aparse_function_output_type\x18\x03 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\x17parseFunctionOutputType\x12H\n!is_parse_function_output_optional\x18\x04 \x01(\x08R\x1disParseFunctionOutputOptional\x12\x42\n\x1eparse_function_input_type_name\x18\x05 \x01(\tR\x1aparseFunctionInputTypeName\x12\x44\n\x1fparse_function_output_type_name\x18\x06 \x01(\tR\x1bparseFunctionOutputTypeName"\xcb\x07\n\x0eStreamResolver\x12\x10\n\x03\x66qn\x18\x01 \x01(\tR\x03\x66qn\x12;\n\x06params\x18\x02 \x03(\x0b\x32#.chalk.graph.v1.StreamResolverParamR\x06params\x12\x38\n\x07outputs\x18\x03 \x03(\x0b\x32\x1e.chalk.graph.v1.ResolverOutputR\x07outputs\x12\x42\n\x0f\x65xplicit_schema\x18\x04 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\x0e\x65xplicitSchema\x12-\n\x04keys\x18\x05 \x03(\x0b\x32\x19.chalk.graph.v1.StreamKeyR\x04keys\x12\x41\n\x06source\x18\x06 \x01(\x0b\x32%.chalk.graph.v1.StreamSourceReferenceB\x02\x18\x01R\x06source\x12\x38\n\nparse_info\x18\x07 \x01(\x0b\x32\x19.chalk.graph.v1.ParseInfoR\tparseInfo\x12.\n\x04mode\x18\x08 \x01(\x0e\x32\x1a.chalk.graph.v1.WindowModeR\x04mode\x12"\n\x0c\x65nvironments\x18\t \x03(\tR\x0c\x65nvironments\x12\x44\n\x10timeout_duration\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationR\x0ftimeoutDuration\x12=\n\x18timestamp_attribute_name\x18\x0b \x01(\tH\x00R\x16timestampAttributeName\x88\x01\x01\x12\x19\n\x05owner\x18\x0c \x01(\tH\x01R\x05owner\x88\x01\x01\x12\x15\n\x03\x64oc\x18\r \x01(\tH\x02R\x03\x64oc\x88\x01\x01\x12&\n\x0cmachine_type\x18\x0e \x01(\tH\x03R\x0bmachineType\x88\x01\x01\x12=\n\x08\x66unction\x18\x0f \x01(\x0b\x32!.chalk.graph.v1.FunctionReferenceR\x08\x66unction\x12\x42\n\tsource_v2\x18\x10 \x01(\x0b\x32%.chalk.graph.v2.StreamSourceReferenceR\x08sourceV2\x12J\n!updates_materialized_aggregations\x18\x11 \x01(\x08R\x1fupdatesMaterializedAggregationsB\x1b\n\x19_timestamp_attribute_nameB\x08\n\x06_ownerB\x06\n\x04_docB\x0f\n\r_machine_type"\x80\x01\n\rResolverState\x12\x35\n\x07initial\x18\x01 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x07initial\x12\x38\n\narrow_type\x18\x02 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType"\xf7\x01\n\x13StreamResolverParam\x12\x46\n\x07message\x18\x01 \x01(\x0b\x32*.chalk.graph.v1.StreamResolverParamMessageH\x00R\x07message\x12Y\n\x0emessage_window\x18\x02 \x01(\x0b\x32\x30.chalk.graph.v1.StreamResolverParamMessageWindowH\x00R\rmessageWindow\x12\x35\n\x05state\x18\x03 \x01(\x0b\x32\x1d.chalk.graph.v1.ResolverStateH\x00R\x05stateB\x06\n\x04type"p\n StreamResolverParamMessageWindow\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x38\n\narrow_type\x18\x02 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType"j\n\x1aStreamResolverParamMessage\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x38\n\narrow_type\x18\x02 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType"\x9f\x02\n\x11\x46unctionReference\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06module\x18\x02 \x01(\tR\x06module\x12\x1b\n\tfile_name\x18\x03 \x01(\tR\x08\x66ileName\x12/\n\x13\x66unction_definition\x18\x04 \x01(\tR\x12\x66unctionDefinition\x12$\n\x0bsource_line\x18\x05 \x01(\x05H\x00R\nsourceLine\x88\x01\x01\x12Z\n\x10\x63\x61ptured_globals\x18\x06 \x03(\x0b\x32/.chalk.graph.v1.FunctionReferenceCapturedGlobalR\x0f\x63\x61pturedGlobalsB\x0e\n\x0c_source_line"\xf3\x06\n\x1f\x46unctionReferenceCapturedGlobal\x12\x1f\n\x0bglobal_name\x18\x03 \x01(\tR\nglobalName\x12I\n\x07\x62uiltin\x18\x01 \x01(\x0b\x32-.chalk.graph.v1.FunctionGlobalCapturedBuiltinH\x00R\x07\x62uiltin\x12Y\n\rfeature_class\x18\x02 \x01(\x0b\x32\x32.chalk.graph.v1.FunctionGlobalCapturedFeatureClassH\x00R\x0c\x66\x65\x61tureClass\x12@\n\x04\x65num\x18\x04 \x01(\x0b\x32*.chalk.graph.v1.FunctionGlobalCapturedEnumH\x00R\x04\x65num\x12\x46\n\x06module\x18\x05 \x01(\x0b\x32,.chalk.graph.v1.FunctionGlobalCapturedModuleH\x00R\x06module\x12Y\n\rmodule_member\x18\x07 \x01(\x0b\x32\x32.chalk.graph.v1.FunctionGlobalCapturedModuleMemberH\x00R\x0cmoduleMember\x12L\n\x08\x66unction\x18\x06 \x01(\x0b\x32..chalk.graph.v1.FunctionGlobalCapturedFunctionH\x00R\x08\x66unction\x12\x46\n\x06struct\x18\x08 \x01(\x0b\x32,.chalk.graph.v1.FunctionGlobalCapturedStructH\x00R\x06struct\x12L\n\x08variable\x18\n \x01(\x0b\x32..chalk.graph.v1.FunctionGlobalCapturedVariableH\x00R\x08variable\x12\x43\n\x05proto\x18\x0b \x01(\x0b\x32+.chalk.graph.v1.FunctionGlobalCapturedProtoH\x00R\x05proto\x12S\n\x10source_reference\x18\t \x01(\x0b\x32#.chalk.graph.v1.SourceFileReferenceH\x01R\x0fsourceReference\x88\x01\x01\x42\x11\n\x0f\x63\x61ptured_globalB\x13\n\x11_source_reference"B\n\x1d\x46unctionGlobalCapturedBuiltin\x12!\n\x0c\x62uiltin_name\x18\x01 \x01(\tR\x0b\x62uiltinName"L\n\x1e\x46unctionGlobalCapturedVariable\x12\x16\n\x06module\x18\x01 \x01(\tR\x06module\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name"\x80\x01\n\x1c\x46unctionGlobalCapturedStruct\x12\x16\n\x06module\x18\x01 \x01(\tR\x06module\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x34\n\x08pa_dtype\x18\x03 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\x07paDtype"\xae\x02\n\x1a\x46unctionGlobalCapturedEnum\x12\x16\n\x06module\x18\x01 \x01(\tR\x06module\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12X\n\nmember_map\x18\x03 \x03(\x0b\x32\x39.chalk.graph.v1.FunctionGlobalCapturedEnum.MemberMapEntryR\tmemberMap\x12/\n\x05\x62\x61ses\x18\x04 \x03(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\x05\x62\x61ses\x1aY\n\x0eMemberMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x05value:\x02\x38\x01"R\n"FunctionGlobalCapturedFeatureClass\x12,\n\x12\x66\x65\x61ture_class_name\x18\x01 \x01(\tR\x10\x66\x65\x61tureClassName"2\n\x1c\x46unctionGlobalCapturedModule\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name"a\n"FunctionGlobalCapturedModuleMember\x12\x1f\n\x0bmodule_name\x18\x01 \x01(\tR\nmoduleName\x12\x1a\n\x08qualname\x18\x02 \x01(\tR\x08qualname"\xd0\x01\n\x1e\x46unctionGlobalCapturedFunction\x12\x16\n\x06source\x18\x01 \x01(\tR\x06source\x12Z\n\x10\x63\x61ptured_globals\x18\x02 \x03(\x0b\x32/.chalk.graph.v1.FunctionReferenceCapturedGlobalR\x0f\x63\x61pturedGlobals\x12\x1b\n\x06module\x18\x03 \x01(\tH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x04 \x01(\tR\x04nameB\t\n\x07_module"\xd5\x01\n\x1b\x46unctionGlobalCapturedProto\x12\x16\n\x06module\x18\x01 \x01(\tR\x06module\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x02\x66\x64\x18\x03 \x01(\x0c\x42\x02\x18\x01R\x02\x66\x64\x12#\n\rserialized_fd\x18\x06 \x01(\x0cR\x0cserializedFd\x12\x34\n\x08pa_dtype\x18\x04 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\x07paDtype\x12\x1b\n\tfull_name\x18\x05 \x01(\tR\x08\x66ullName"\x7f\n\x13SourceFileReference\x12)\n\x05range\x18\x01 \x01(\x0b\x32\x13.chalk.lsp.v1.RangeR\x05range\x12\x17\n\x04\x63ode\x18\x02 \x01(\tH\x00R\x04\x63ode\x88\x01\x01\x12\x1b\n\tfile_name\x18\x03 \x01(\tR\x08\x66ileNameB\x07\n\x05_code"Y\n\tStreamKey\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12:\n\x07\x66\x65\x61ture\x18\x02 \x01(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x07\x66\x65\x61ture"\xaa\x04\n\x13SQLResolverSettings\x12\x37\n\tfinalizer\x18\x01 \x01(\x0e\x32\x19.chalk.graph.v1.FinalizerR\tfinalizer\x12[\n\x14incremental_settings\x18\x02 \x01(\x0b\x32#.chalk.graph.v1.IncrementalSettingsH\x00R\x13incrementalSettings\x88\x01\x01\x12^\n\x0f\x66ields_root_fqn\x18\x03 \x03(\x0b\x32\x36.chalk.graph.v1.SQLResolverSettings.FieldsRootFqnEntryR\rfieldsRootFqn\x12x\n\x19\x65scaped_param_name_to_fqn\x18\x04 \x03(\x0b\x32>.chalk.graph.v1.SQLResolverSettings.EscapedParamNameToFqnEntryR\x15\x65scapedParamNameToFqn\x1a@\n\x12\x46ieldsRootFqnEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1aH\n\x1a\x45scapedParamNameToFqnEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x17\n\x15_incremental_settings"\xc3\x02\n\x13IncrementalSettings\x12\x33\n\x04mode\x18\x01 \x01(\x0e\x32\x1f.chalk.graph.v1.IncrementalModeR\x04mode\x12G\n\x0flookback_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x0elookbackPeriod\x88\x01\x01\x12\x32\n\x12incremental_column\x18\x03 \x01(\tH\x01R\x11incrementalColumn\x88\x01\x01\x12O\n\x0etimestamp_mode\x18\x04 \x01(\x0e\x32(.chalk.graph.v1.IncrementalTimestampModeR\rtimestampModeB\x12\n\x10_lookback_periodB\x15\n\x13_incremental_column"\xc8\x06\n\x16SQLResolverCommentDict\x12\x19\n\x05total\x18\x01 \x01(\x08H\x00R\x05total\x88\x01\x01\x12\x1b\n\x06source\x18\x02 \x01(\tH\x01R\x06source\x88\x01\x01\x12\x1f\n\x08resolves\x18\x03 \x01(\tH\x02R\x08resolves\x88\x01\x01\x12!\n\tnamespace\x18\x04 \x01(\tH\x03R\tnamespace\x88\x01\x01\x12J\n\x0bincremental\x18\x05 \x01(\x0b\x32#.chalk.graph.v1.IncrementalSettingsH\x04R\x0bincremental\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12 \n\x0b\x65nvironment\x18\x07 \x03(\tR\x0b\x65nvironment\x12\x34\n\x05\x63ount\x18\x08 \x01(\x0e\x32\x19.chalk.graph.v1.FinalizerH\x05R\x05\x63ount\x88\x01\x01\x12\x31\n\x04\x63ron\x18\t \x01(\x0b\x32\x18.chalk.graph.v1.ScheduleH\x06R\x04\x63ron\x88\x01\x01\x12&\n\x0cmachine_type\x18\n \x01(\tH\x07R\x0bmachineType\x88\x01\x01\x12\x19\n\x05owner\x18\x0b \x01(\tH\x08R\x05owner\x88\x01\x01\x12\x17\n\x04type\x18\x0c \x01(\tH\tR\x04type\x88\x01\x01\x12\x1d\n\x07timeout\x18\r \x01(\tH\nR\x07timeout\x88\x01\x01\x12J\n\x06\x66ields\x18\x0e \x03(\x0b\x32\x32.chalk.graph.v1.SQLResolverCommentDict.FieldsEntryR\x06\x66ields\x12\x1b\n\tunique_on\x18\x0f \x03(\tR\x08uniqueOn\x12%\n\x0epartitioned_by\x18\x10 \x03(\tR\rpartitionedBy\x1a\x39\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_totalB\t\n\x07_sourceB\x0b\n\t_resolvesB\x0c\n\n_namespaceB\x0e\n\x0c_incrementalB\x08\n\x06_countB\x07\n\x05_cronB\x0f\n\r_machine_typeB\x08\n\x06_ownerB\x07\n\x05_typeB\n\n\x08_timeout"\xed\x01\n\x0fSQLResolverInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x08\x66ilepath\x18\x02 \x01(\tH\x00R\x08\x66ilepath\x88\x01\x01\x12\x1d\n\nsql_string\x18\x03 \x01(\tR\tsqlString\x12_\n\x15override_comment_dict\x18\x04 \x01(\x0b\x32&.chalk.graph.v1.SQLResolverCommentDictH\x01R\x13overrideCommentDict\x88\x01\x01\x42\x0b\n\t_filepathB\x18\n\x16_override_comment_dict"\x8c\x01\n\x19\x43ronFilterWithFeatureArgs\x12\x39\n\x06\x66ilter\x18\x01 \x01(\x0b\x32!.chalk.graph.v1.FunctionReferenceR\x06\x66ilter\x12\x34\n\x04\x61rgs\x18\x02 \x03(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x04\x61rgs"\xe1\x01\n\x08Schedule\x12\x1a\n\x07\x63rontab\x18\x01 \x01(\tH\x00R\x07\x63rontab\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x08\x64uration\x12\x39\n\x06\x66ilter\x18\x03 \x01(\x0b\x32!.chalk.graph.v1.FunctionReferenceR\x06\x66ilter\x12\x39\n\x06sample\x18\x04 \x01(\x0b\x32!.chalk.graph.v1.FunctionReferenceR\x06sampleB\n\n\x08schedule"\xf8\x03\n\x11\x46\x65\x61tureValidation\x12\x16\n\x03min\x18\x01 \x01(\x02\x42\x02\x18\x01H\x00R\x03min\x12\x16\n\x03max\x18\x02 \x01(\x02\x42\x02\x18\x01H\x00R\x03max\x12#\n\nmin_length\x18\x03 \x01(\rB\x02\x18\x01H\x00R\tminLength\x12#\n\nmax_length\x18\x04 \x01(\rB\x02\x18\x01H\x00R\tmaxLength\x12:\n\tmin_arrow\x18\x06 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueH\x00R\x08minArrow\x12:\n\tmax_arrow\x18\x07 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueH\x00R\x08maxArrow\x12G\n\x10min_length_arrow\x18\x08 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueH\x00R\x0eminLengthArrow\x12G\n\x10max_length_arrow\x18\t \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueH\x00R\x0emaxLengthArrow\x12\x39\n\x08\x63ontains\x18\n \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueH\x00R\x08\x63ontains\x12\x16\n\x06strict\x18\x05 \x01(\x08R\x06strictB\x0c\n\nvalidation"A\n\x0bVersionInfo\x12\x18\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\rR\x07\x64\x65\x66\x61ult\x12\x18\n\x07maximum\x18\x02 \x01(\rR\x07maximum"\x93\x01\n\x10StrictValidation\x12:\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32 .chalk.graph.v1.FeatureReferenceR\x07\x66\x65\x61ture\x12\x43\n\x0bvalidations\x18\x02 \x03(\x0b\x32!.chalk.graph.v1.FeatureValidationR\x0bvalidations"\x89\x01\n\x0e\x46\x65\x61tureEncoder\x12l\n\x19global_function_reference\x18\x01 \x01(\x0b\x32..chalk.graph.v1.FunctionGlobalCapturedFunctionH\x00R\x17globalFunctionReferenceB\t\n\x07\x65ncoder"\x89\x01\n\x0e\x46\x65\x61tureDecoder\x12l\n\x19global_function_reference\x18\x01 \x01(\x0b\x32..chalk.graph.v1.FunctionGlobalCapturedFunctionH\x00R\x17globalFunctionReferenceB\t\n\x07\x64\x65\x63oder"\xf7\x01\n\x13\x46\x65\x61tureRichTypeInfo\x12J\n#rich_type_is_same_as_primitive_type\x18\x01 \x01(\x08R\x1drichTypeIsSameAsPrimitiveType\x12=\n\x07\x65ncoder\x18\x02 \x01(\x0b\x32\x1e.chalk.graph.v1.FeatureEncoderH\x00R\x07\x65ncoder\x88\x01\x01\x12=\n\x07\x64\x65\x63oder\x18\x03 \x01(\x0b\x32\x1e.chalk.graph.v1.FeatureDecoderH\x01R\x07\x64\x65\x63oder\x88\x01\x01\x42\n\n\x08_encoderB\n\n\x08_decoder*\x9d\x02\n\rCacheStrategy\x12\x1e\n\x1a\x43\x41\x43HE_STRATEGY_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43\x41\x43HE_STRATEGY_ALL\x10\x01\x12\x1b\n\x17\x43\x41\x43HE_STRATEGY_NO_NULLS\x10\x02\x12\x1e\n\x1a\x43\x41\x43HE_STRATEGY_EVICT_NULLS\x10\x03\x12\x1e\n\x1a\x43\x41\x43HE_STRATEGY_NO_DEFAULTS\x10\x04\x12!\n\x1d\x43\x41\x43HE_STRATEGY_EVICT_DEFAULTS\x10\x05\x12\'\n#CACHE_STRATEGY_NO_NULLS_OR_DEFAULTS\x10\x06\x12+\n\'CACHE_STRATEGY_EVICT_NULLS_AND_DEFAULTS\x10\x07*b\n\x0cResolverKind\x12\x1d\n\x19RESOLVER_KIND_UNSPECIFIED\x10\x00\x12\x18\n\x14RESOLVER_KIND_ONLINE\x10\x01\x12\x19\n\x15RESOLVER_KIND_OFFLINE\x10\x02*Z\n\x0cResourceHint\x12\x1d\n\x19RESOURCE_HINT_UNSPECIFIED\x10\x00\x12\x15\n\x11RESOURCE_HINT_CPU\x10\x01\x12\x14\n\x10RESOURCE_HINT_IO\x10\x02*|\n\tFinalizer\x12\x19\n\x15\x46INALIZER_UNSPECIFIED\x10\x00\x12\x19\n\x15\x46INALIZER_ONE_OR_NONE\x10\x01\x12\x11\n\rFINALIZER_ONE\x10\x02\x12\x13\n\x0f\x46INALIZER_FIRST\x10\x03\x12\x11\n\rFINALIZER_ALL\x10\x04*\x89\x01\n\x0fIncrementalMode\x12 \n\x1cINCREMENTAL_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14INCREMENTAL_MODE_ROW\x10\x01\x12\x1a\n\x16INCREMENTAL_MODE_GROUP\x10\x02\x12\x1e\n\x1aINCREMENTAL_MODE_PARAMETER\x10\x03*\xab\x01\n\x18IncrementalTimestampMode\x12*\n&INCREMENTAL_TIMESTAMP_MODE_UNSPECIFIED\x10\x00\x12+\n\'INCREMENTAL_TIMESTAMP_MODE_FEATURE_TIME\x10\x01\x12\x36\n2INCREMENTAL_TIMESTAMP_MODE_RESOLVER_EXECUTION_TIME\x10\x02*t\n\nWindowMode\x12\x1b\n\x17WINDOW_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16WINDOW_MODE_CONTINUOUS\x10\x01\x12\x18\n\x14WINDOW_MODE_TUMBLING\x10\x02\x12\x13\n\x0fWINDOW_MODE_CDC\x10\x03\x42z\n\x12\x63om.chalk.graph.v1B\nGraphProtoP\x01\xa2\x02\x03\x43GX\xaa\x02\x0e\x43halk.Graph.V1\xca\x02\x0e\x43halk\\Graph\\V1\xe2\x02\x1a\x43halk\\Graph\\V1\\GPBMetadata\xea\x02\x10\x43halk::Graph::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.graph.v1.graph_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\022com.chalk.graph.v1B\nGraphProtoP\001\242\002\003CGX\252\002\016Chalk.Graph.V1\312\002\016Chalk\\Graph\\V1\342\002\032Chalk\\Graph\\V1\\GPBMetadata\352\002\020Chalk::Graph::V1"
    _globals["_GRAPH"].fields_by_name["database_sources"]._options = None
    _globals["_GRAPH"].fields_by_name["database_sources"]._serialized_options = b"\030\001"
    _globals["_GRAPH"].fields_by_name["stream_sources"]._options = None
    _globals["_GRAPH"].fields_by_name["stream_sources"]._serialized_options = b"\030\001"
    _globals["_NAMEDQUERY_METAENTRY"]._options = None
    _globals["_NAMEDQUERY_METAENTRY"]._serialized_options = b"8\001"
    _globals["_NAMEDQUERY_STALENESSENTRY"]._options = None
    _globals["_NAMEDQUERY_STALENESSENTRY"]._serialized_options = b"8\001"
    _globals["_NAMEDQUERY_PLANNEROPTIONSENTRY"]._options = None
    _globals["_NAMEDQUERY_PLANNEROPTIONSENTRY"]._serialized_options = b"8\001"
    _globals["_RESOLVER"].fields_by_name["data_sources"]._options = None
    _globals["_RESOLVER"].fields_by_name["data_sources"]._serialized_options = b"\030\001"
    _globals["_SINKRESOLVER"].fields_by_name["stream_source"]._options = None
    _globals["_SINKRESOLVER"].fields_by_name["stream_source"]._serialized_options = b"\030\001"
    _globals["_SINKRESOLVER"].fields_by_name["database_source"]._options = None
    _globals["_SINKRESOLVER"].fields_by_name["database_source"]._serialized_options = b"\030\001"
    _globals["_STREAMRESOLVER"].fields_by_name["source"]._options = None
    _globals["_STREAMRESOLVER"].fields_by_name["source"]._serialized_options = b"\030\001"
    _globals["_FUNCTIONGLOBALCAPTUREDENUM_MEMBERMAPENTRY"]._options = None
    _globals["_FUNCTIONGLOBALCAPTUREDENUM_MEMBERMAPENTRY"]._serialized_options = b"8\001"
    _globals["_FUNCTIONGLOBALCAPTUREDPROTO"].fields_by_name["fd"]._options = None
    _globals["_FUNCTIONGLOBALCAPTUREDPROTO"].fields_by_name["fd"]._serialized_options = b"\030\001"
    _globals["_SQLRESOLVERSETTINGS_FIELDSROOTFQNENTRY"]._options = None
    _globals["_SQLRESOLVERSETTINGS_FIELDSROOTFQNENTRY"]._serialized_options = b"8\001"
    _globals["_SQLRESOLVERSETTINGS_ESCAPEDPARAMNAMETOFQNENTRY"]._options = None
    _globals["_SQLRESOLVERSETTINGS_ESCAPEDPARAMNAMETOFQNENTRY"]._serialized_options = b"8\001"
    _globals["_SQLRESOLVERCOMMENTDICT_FIELDSENTRY"]._options = None
    _globals["_SQLRESOLVERCOMMENTDICT_FIELDSENTRY"]._serialized_options = b"8\001"
    _globals["_FEATUREVALIDATION"].fields_by_name["min"]._options = None
    _globals["_FEATUREVALIDATION"].fields_by_name["min"]._serialized_options = b"\030\001"
    _globals["_FEATUREVALIDATION"].fields_by_name["max"]._options = None
    _globals["_FEATUREVALIDATION"].fields_by_name["max"]._serialized_options = b"\030\001"
    _globals["_FEATUREVALIDATION"].fields_by_name["min_length"]._options = None
    _globals["_FEATUREVALIDATION"].fields_by_name["min_length"]._serialized_options = b"\030\001"
    _globals["_FEATUREVALIDATION"].fields_by_name["max_length"]._options = None
    _globals["_FEATUREVALIDATION"].fields_by_name["max_length"]._serialized_options = b"\030\001"
    _globals["_CACHESTRATEGY"]._serialized_start = 19779
    _globals["_CACHESTRATEGY"]._serialized_end = 20064
    _globals["_RESOLVERKIND"]._serialized_start = 20066
    _globals["_RESOLVERKIND"]._serialized_end = 20164
    _globals["_RESOURCEHINT"]._serialized_start = 20166
    _globals["_RESOURCEHINT"]._serialized_end = 20256
    _globals["_FINALIZER"]._serialized_start = 20258
    _globals["_FINALIZER"]._serialized_end = 20382
    _globals["_INCREMENTALMODE"]._serialized_start = 20385
    _globals["_INCREMENTALMODE"]._serialized_end = 20522
    _globals["_INCREMENTALTIMESTAMPMODE"]._serialized_start = 20525
    _globals["_INCREMENTALTIMESTAMPMODE"]._serialized_end = 20696
    _globals["_WINDOWMODE"]._serialized_start = 20698
    _globals["_WINDOWMODE"]._serialized_end = 20814
    _globals["_GRAPH"]._serialized_start = 262
    _globals["_GRAPH"]._serialized_end = 994
    _globals["_OVERLAYGRAPH"]._serialized_start = 997
    _globals["_OVERLAYGRAPH"]._serialized_end = 1287
    _globals["_NAMEDQUERY"]._serialized_start = 1290
    _globals["_NAMEDQUERY"]._serialized_end = 2332
    _globals["_NAMEDQUERY_METAENTRY"]._serialized_start = 2005
    _globals["_NAMEDQUERY_METAENTRY"]._serialized_end = 2060
    _globals["_NAMEDQUERY_STALENESSENTRY"]._serialized_start = 2062
    _globals["_NAMEDQUERY_STALENESSENTRY"]._serialized_end = 2149
    _globals["_NAMEDQUERY_PLANNEROPTIONSENTRY"]._serialized_start = 2151
    _globals["_NAMEDQUERY_PLANNEROPTIONSENTRY"]._serialized_end = 2216
    _globals["_FEATURESET"]._serialized_start = 2335
    _globals["_FEATURESET"]._serialized_end = 2761
    _globals["_FEATURETYPE"]._serialized_start = 2764
    _globals["_FEATURETYPE"]._serialized_end = 3182
    _globals["_FEATUREREFERENCE"]._serialized_start = 3185
    _globals["_FEATUREREFERENCE"]._serialized_end = 3354
    _globals["_DATAFRAMETYPE"]._serialized_start = 3357
    _globals["_DATAFRAMETYPE"]._serialized_end = 3664
    _globals["_GROUPBYFEATURETYPE"]._serialized_start = 3667
    _globals["_GROUPBYFEATURETYPE"]._serialized_end = 4454
    _globals["_SCALARFEATURETYPE"]._serialized_start = 4457
    _globals["_SCALARFEATURETYPE"]._serialized_end = 6009
    _globals["_HASONEFEATURETYPE"]._serialized_start = 6012
    _globals["_HASONEFEATURETYPE"]._serialized_end = 6473
    _globals["_HASMANYFEATURETYPE"]._serialized_start = 6476
    _globals["_HASMANYFEATURETYPE"]._serialized_end = 6986
    _globals["_FEATURETIMEFEATURETYPE"]._serialized_start = 6989
    _globals["_FEATURETIMEFEATURETYPE"]._serialized_end = 7257
    _globals["_WINDOWEDFEATURETYPE"]._serialized_start = 7260
    _globals["_WINDOWEDFEATURETYPE"]._serialized_end = 7545
    _globals["_WINDOWAGGREGATION"]._serialized_start = 7548
    _globals["_WINDOWAGGREGATION"]._serialized_end = 8613
    _globals["_WINDOWINFO"]._serialized_start = 8616
    _globals["_WINDOWINFO"]._serialized_end = 8773
    _globals["_FEATUREINPUT"]._serialized_start = 8776
    _globals["_FEATUREINPUT"]._serialized_end = 8916
    _globals["_RESOLVERINPUT"]._serialized_start = 8919
    _globals["_RESOLVERINPUT"]._serialized_end = 9110
    _globals["_RESOLVEROUTPUT"]._serialized_start = 9113
    _globals["_RESOLVEROUTPUT"]._serialized_end = 9254
    _globals["_RESOLVER"]._serialized_start = 9257
    _globals["_RESOLVER"]._serialized_end = 10530
    _globals["_SINKRESOLVER"]._serialized_start = 10533
    _globals["_SINKRESOLVER"]._serialized_end = 11494
    _globals["_PARSEINFO"]._serialized_start = 11497
    _globals["_PARSEINFO"]._serialized_end = 11968
    _globals["_STREAMRESOLVER"]._serialized_start = 11971
    _globals["_STREAMRESOLVER"]._serialized_end = 12942
    _globals["_RESOLVERSTATE"]._serialized_start = 12945
    _globals["_RESOLVERSTATE"]._serialized_end = 13073
    _globals["_STREAMRESOLVERPARAM"]._serialized_start = 13076
    _globals["_STREAMRESOLVERPARAM"]._serialized_end = 13323
    _globals["_STREAMRESOLVERPARAMMESSAGEWINDOW"]._serialized_start = 13325
    _globals["_STREAMRESOLVERPARAMMESSAGEWINDOW"]._serialized_end = 13437
    _globals["_STREAMRESOLVERPARAMMESSAGE"]._serialized_start = 13439
    _globals["_STREAMRESOLVERPARAMMESSAGE"]._serialized_end = 13545
    _globals["_FUNCTIONREFERENCE"]._serialized_start = 13548
    _globals["_FUNCTIONREFERENCE"]._serialized_end = 13835
    _globals["_FUNCTIONREFERENCECAPTUREDGLOBAL"]._serialized_start = 13838
    _globals["_FUNCTIONREFERENCECAPTUREDGLOBAL"]._serialized_end = 14721
    _globals["_FUNCTIONGLOBALCAPTUREDBUILTIN"]._serialized_start = 14723
    _globals["_FUNCTIONGLOBALCAPTUREDBUILTIN"]._serialized_end = 14789
    _globals["_FUNCTIONGLOBALCAPTUREDVARIABLE"]._serialized_start = 14791
    _globals["_FUNCTIONGLOBALCAPTUREDVARIABLE"]._serialized_end = 14867
    _globals["_FUNCTIONGLOBALCAPTUREDSTRUCT"]._serialized_start = 14870
    _globals["_FUNCTIONGLOBALCAPTUREDSTRUCT"]._serialized_end = 14998
    _globals["_FUNCTIONGLOBALCAPTUREDENUM"]._serialized_start = 15001
    _globals["_FUNCTIONGLOBALCAPTUREDENUM"]._serialized_end = 15303
    _globals["_FUNCTIONGLOBALCAPTUREDENUM_MEMBERMAPENTRY"]._serialized_start = 15214
    _globals["_FUNCTIONGLOBALCAPTUREDENUM_MEMBERMAPENTRY"]._serialized_end = 15303
    _globals["_FUNCTIONGLOBALCAPTUREDFEATURECLASS"]._serialized_start = 15305
    _globals["_FUNCTIONGLOBALCAPTUREDFEATURECLASS"]._serialized_end = 15387
    _globals["_FUNCTIONGLOBALCAPTUREDMODULE"]._serialized_start = 15389
    _globals["_FUNCTIONGLOBALCAPTUREDMODULE"]._serialized_end = 15439
    _globals["_FUNCTIONGLOBALCAPTUREDMODULEMEMBER"]._serialized_start = 15441
    _globals["_FUNCTIONGLOBALCAPTUREDMODULEMEMBER"]._serialized_end = 15538
    _globals["_FUNCTIONGLOBALCAPTUREDFUNCTION"]._serialized_start = 15541
    _globals["_FUNCTIONGLOBALCAPTUREDFUNCTION"]._serialized_end = 15749
    _globals["_FUNCTIONGLOBALCAPTUREDPROTO"]._serialized_start = 15752
    _globals["_FUNCTIONGLOBALCAPTUREDPROTO"]._serialized_end = 15965
    _globals["_SOURCEFILEREFERENCE"]._serialized_start = 15967
    _globals["_SOURCEFILEREFERENCE"]._serialized_end = 16094
    _globals["_STREAMKEY"]._serialized_start = 16096
    _globals["_STREAMKEY"]._serialized_end = 16185
    _globals["_SQLRESOLVERSETTINGS"]._serialized_start = 16188
    _globals["_SQLRESOLVERSETTINGS"]._serialized_end = 16742
    _globals["_SQLRESOLVERSETTINGS_FIELDSROOTFQNENTRY"]._serialized_start = 16579
    _globals["_SQLRESOLVERSETTINGS_FIELDSROOTFQNENTRY"]._serialized_end = 16643
    _globals["_SQLRESOLVERSETTINGS_ESCAPEDPARAMNAMETOFQNENTRY"]._serialized_start = 16645
    _globals["_SQLRESOLVERSETTINGS_ESCAPEDPARAMNAMETOFQNENTRY"]._serialized_end = 16717
    _globals["_INCREMENTALSETTINGS"]._serialized_start = 16745
    _globals["_INCREMENTALSETTINGS"]._serialized_end = 17068
    _globals["_SQLRESOLVERCOMMENTDICT"]._serialized_start = 17071
    _globals["_SQLRESOLVERCOMMENTDICT"]._serialized_end = 17911
    _globals["_SQLRESOLVERCOMMENTDICT_FIELDSENTRY"]._serialized_start = 17723
    _globals["_SQLRESOLVERCOMMENTDICT_FIELDSENTRY"]._serialized_end = 17780
    _globals["_SQLRESOLVERINFO"]._serialized_start = 17914
    _globals["_SQLRESOLVERINFO"]._serialized_end = 18151
    _globals["_CRONFILTERWITHFEATUREARGS"]._serialized_start = 18154
    _globals["_CRONFILTERWITHFEATUREARGS"]._serialized_end = 18294
    _globals["_SCHEDULE"]._serialized_start = 18297
    _globals["_SCHEDULE"]._serialized_end = 18522
    _globals["_FEATUREVALIDATION"]._serialized_start = 18525
    _globals["_FEATUREVALIDATION"]._serialized_end = 19029
    _globals["_VERSIONINFO"]._serialized_start = 19031
    _globals["_VERSIONINFO"]._serialized_end = 19096
    _globals["_STRICTVALIDATION"]._serialized_start = 19099
    _globals["_STRICTVALIDATION"]._serialized_end = 19246
    _globals["_FEATUREENCODER"]._serialized_start = 19249
    _globals["_FEATUREENCODER"]._serialized_end = 19386
    _globals["_FEATUREDECODER"]._serialized_start = 19389
    _globals["_FEATUREDECODER"]._serialized_end = 19526
    _globals["_FEATURERICHTYPEINFO"]._serialized_start = 19529
    _globals["_FEATURERICHTYPEINFO"]._serialized_end = 19776
# @@protoc_insertion_point(module_scope)
